<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

$config['post_category_id_resource_type_page_template'] = 1;
$config['post_category_parent_id'] = 2;

$config['post_id_resource_type_page_template'] = 1;

$config['post_thumbnail_path'] = '/assets/uploads/multimedia/images/';
$config['post_thumbnail_width'] = 200;
$config['post_thumbnail_height'] = 200;

$config['post_per_page'] = 12;
