<div class="container">
    <div class="row">
        <?php foreach ($items as $item) : ?>
            <div class="col">
                <div class="card">
                    <a href="<?= page_url($item['alias']) ?>">
                        <img alt="<?= $item['title'] ?>"
                             src="<?= get_instance()->config->item('post_thumbnail_path') . $item['thumbnail'] ?>"/>
                    </a>
                    <div class="card-body">
                        <a href="<?= page_url($item['category_alias']) ?>"><strong><?= $item['category_title'] ?></strong></a>
                        <p class="card-text">
                            <a href="<?= page_url($item['alias']) ?>"><?= $item['title'] ?></a>
                        </p>
                        <div class="mb-1 text-muted"><?= date('F d, Y', strtotime($item['updated'])); ?></div>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>

    <div class="pagination">
        <?= $pagination ?>
    </div>
</div>