CREATE TABLE IF NOT EXISTS `post` ( 
`id_post` int(11) NOT NULL AUTO_INCREMENT,
`thumbnail` varchar(255) CHARACTER SET utf8 NOT NULL,
`title` varchar(255) CHARACTER SET utf8 NOT NULL,
`short_desc` text,
`content` text NOT NULL,
`id_resource_type_page` int(11),
PRIMARY KEY (`id_post`) 
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

CREATE TABLE IF NOT EXISTS `post_category` ( 
`id_post_category` int(11) NOT NULL AUTO_INCREMENT,
`title` varchar(255) CHARACTER SET utf8 NOT NULL,
`view_order` int(11),
`id_resource_type_page` int(11),
PRIMARY KEY (`id_post_category`) 
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
