<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Post_admin extends \Ciext\Controller\AbstractAdminController
{

    public function posts()
    {
        $this->load->model('post/post_crud');

        return ['content' => $this->post_crud->render(), 'title' => $this->lang->line('Posts')];
    }

    public function categories()
    {
        $this->load->model('post/post_category_crud');

        return ['content' => $this->post_category_crud->render(), 'title' => $this->lang->line('Categories')];
    }
}
